==> xmonad-0.18.0-146.1-loong64.pkg.tar.zst: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad
version:              0.18.0
visibility:           public
id:                   xmonad-0.18.0-9q3EgsUWBkZ6tGkOOAtZIz
key:                  xmonad-0.18.0-9q3EgsUWBkZ6tGkOOAtZIz
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:
    Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
    Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
    Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
    Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
    Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
    Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
    Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
    Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
    Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
    Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
    Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
    Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
    Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
    Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion, Tony Zorman

homepage:             http://xmonad.org
synopsis:             A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.

category:             System
abi:                  ba4aa20d25b52226237098e88446c191
exposed:              True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet

hidden-modules:       Paths_xmonad
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-0.18.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-0.18.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-0.18.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad
hs-libraries:         HSxmonad-0.18.0-9q3EgsUWBkZ6tGkOOAtZIz
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay base-4.18.2.1 containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 process-1.6.19.0
    setlocale-1.0.0.10-HH45IWXdMTEGcVsXOuIxfh time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html:         /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.18.0-147-loong64.pkg.tar.zst: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad
version:              0.18.0
visibility:           public
id:                   xmonad-0.18.0-7ncefdvtZDKFFjo51IQreA
key:                  xmonad-0.18.0-7ncefdvtZDKFFjo51IQreA
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:
    Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
    Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
    Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
    Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
    Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
    Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
    Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
    Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
    Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
    Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
    Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
    Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
    Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
    Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion, Tony Zorman

homepage:             http://xmonad.org
synopsis:             A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.

category:             System
abi:                  8ec6999919227a15ca85549a4908008c
exposed:              True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet

hidden-modules:       Paths_xmonad
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-0.18.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-0.18.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-0.18.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad
hs-libraries:         HSxmonad-0.18.0-7ncefdvtZDKFFjo51IQreA
depends:
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay base-4.18.2.1 containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 process-1.6.19.0
    setlocale-1.0.0.10-HH45IWXdMTEGcVsXOuIxfh time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html:         /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
